// ESP32 IOShield Pin and Address Assignments

#ifndef ESP32_IOSHIELD_h
#define ESP32_IOSHIELD_h

// Note that the IOShield may only be configured (HW & SW) for EITHER I2C OR TM1638
// I2C and TM1638 can not be used/configured simultaneously!

// I2C Data -----------------------------------------------------------------------

// I2C Pins
#define ESP32IO_SDA_PIN			21
#define ESP32IO_SCL_PIN			22

// With A0, A1 and A2 of PCF8574 LOW,  I2C address is 0x20
// With A0, A1 and A2 of PCF8574 HIGH (Default),  I2C address is 0x38
#define ESP32IO_PCF8574_ADDR 0x38

// TM1638 Data --------------------------------------------------------------------

// TM1638 Pins
#define ESP32IO_DATA_PIN		21
#define ESP32IO_CLOCK_PIN		22
#define ESP32IO_STROBE_PIN	23

// --------------------------------------------------------------------------------

// Switch Pins
#define ESP32IO_S1_PIN			17
#define ESP32IO_S2_PIN			16

// Relay Pins
#define ESP32IO_R1_PIN			25
#define ESP32IO_R2_PIN			26
#define ESP32IO_R3_PIN			27
#define ESP32IO_R4_PIN			12

// Thermister Pins
#define ESP32IO_T1_PIN			36
#define ESP32IO_T2_PIN			39
#define ESP32IO_T3_PIN			34
#define ESP32IO_T4_PIN			35
#define ESP32IO_T5_PIN			32
#define ESP32IO_T6_PIN			33

// Thermister Power Pin
#define ESP32IO_T_PWR_PIN		13

// --------------------------------------------------------------------------------

extern int ESP32IO_SwitchPin[2];
extern int ESP32IO_RelayPin[4];
extern int ESP32IO_ThermPin[6];

// Helper Functions

void ESP32_IOShield_Init(void);
int  ESP32_IOShield_SwitchState(int s);
void ESP32_IOShield_SetRelay(int r, int s);

#endif